Skip to main content

This CGIT instance is deprecated, and repositories have been moved to Gitlab or Github. See the repository descriptions for specific locations.

summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorvbhadrir2005-10-26 18:07:05 +0000
committervbhadrir2005-10-26 18:07:05 +0000
commitfdae290e4392aa11357e1cc473030eddaffc8eb7 (patch)
tree54a538ba1ff33ad0d9ef05ea4f044ceb52780d04
parentbf6e29497944443029114fdea5b2b8a8a3247c1a (diff)
downloadwebtools.common-fdae290e4392aa11357e1cc473030eddaffc8eb7.tar.gz
webtools.common-fdae290e4392aa11357e1cc473030eddaffc8eb7.tar.xz
webtools.common-fdae290e4392aa11357e1cc473030eddaffc8eb7.zip
[113621] reaction to deployable changes: committed for JL
-rw-r--r--plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/ModuleCoreNature.java2
-rw-r--r--plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ArtifactEditModel.java2
-rw-r--r--plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ModuleStructuralModel.java2
-rw-r--r--plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/builder/DependencyGraphManager.java11
-rw-r--r--plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/util/IModuleConstants.java2
-rw-r--r--plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/resources/IVirtualComponent.java2
6 files changed, 12 insertions, 9 deletions
diff --git a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/ModuleCoreNature.java b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/ModuleCoreNature.java
index 375581bce..51644c7a5 100644
--- a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/ModuleCoreNature.java
+++ b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/ModuleCoreNature.java
@@ -74,7 +74,7 @@ import org.eclipse.wst.common.project.facet.core.ProjectFacetsManager;
* {@see org.eclipse.wst.common.internal.emfworkbench.integration.EditModel} that manages
* resources associated with the Module Structural Metamodel. As an EditModel, the
* {@see org.eclipse.wst.common.modulecore.ModuleStructuralModel}  references EMF resources,
-* that contain EMF models -- in this case, the EMF model of <i>.wtpmodules </i> file.
+* that contain EMF models -- in this case, the EMF model of <i>.component </i> file.
* </p>
* <p>
* Clients are encouraged to use the Edit Facade pattern (via
diff --git a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ArtifactEditModel.java b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ArtifactEditModel.java
index 76561bc0a..d80b56b0c 100644
--- a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ArtifactEditModel.java
+++ b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ArtifactEditModel.java
@@ -244,7 +244,7 @@ public class ArtifactEditModel extends EditModel implements IAdaptable {
resourceToProcess = (Resource) theResources.get(i);
if (resourceToProcess == null) continue;
String lastSegment = resourceToProcess.getURI().lastSegment();
- if (null != lastSegment && lastSegment.equals(IModuleConstants.WTPMODULE_FILE_NAME)) continue;
+ if (null != lastSegment && lastSegment.equals(IModuleConstants.COMPONENT_FILE_NAME)) continue;
resourceResource = WorkbenchResourceHelper.getFile(resourceToProcess);
if (resourceResource != null) {
virtualResources = ComponentCore.createResources(resourceResource);
diff --git a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ModuleStructuralModel.java b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ModuleStructuralModel.java
index ea6aae12b..47ba60f2c 100644
--- a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ModuleStructuralModel.java
+++ b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/ModuleStructuralModel.java
@@ -32,7 +32,7 @@ import org.eclipse.wst.common.internal.emfworkbench.integration.EditModel;
* {@see org.eclipse.wst.common.internal.emfworkbench.integration.EditModel}&nbsp;that manages
* resources associated with the Module Structural Metamodel. As an EditModel, the
* {@see org.eclipse.wst.common.modulecore.ModuleStructuralModel}&nbsp; references EMF resources,
-* that contain EMF models -- in this case, the EMF model of <i>.wtpmodules </i> file.
+* that contain EMF models -- in this case, the EMF model of <i>.component </i> file.
* </p>
* <p>
* Clients are encouraged to use the Edit Facade pattern (via
diff --git a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/util/IModuleConstants.java b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/util/IModuleConstants.java
index c59f027c0..3fa76da57 100644
--- a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/util/IModuleConstants.java
+++ b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/util/IModuleConstants.java
@@ -19,6 +19,8 @@ import org.eclipse.core.runtime.Path;
*/
public interface IModuleConstants {
+ public final static String COMPONENT_FILE_NAME = ".component"; //$NON-NLS-1$
+ public final static Path COMPONENT_FILE_PATH = new Path(".settings/"+COMPONENT_FILE_NAME); //$NON-NLS-1$
public final static String WTPMODULE_FILE_NAME = ".wtpmodules"; //$NON-NLS-1$
public final static Path WTPMODULE_FILE_PATH = new Path(WTPMODULE_FILE_NAME); //$NON-NLS-1$
public final static String MODULE_PLUG_IN_ID = "org.eclipse.wst.common.modulecore"; //$NON-NLS-1$
diff --git a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/resources/IVirtualComponent.java b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/resources/IVirtualComponent.java
index bc029c905..c010a7a56 100644
--- a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/resources/IVirtualComponent.java
+++ b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/resources/IVirtualComponent.java
@@ -18,7 +18,7 @@ import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.Path;
/**
- * Represents a component as defined by the .wtpmodules file.
+ * Represents a component as defined by the .component file.
* <p>
* A component is a container of virtual resources which has other features that describe the
* component including:

Back to the top
diff --git a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/builder/DependencyGraphManager.java b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/builder/DependencyGraphManager.java
index 700b64177..c71dffd05 100644
--- a/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/builder/DependencyGraphManager.java
+++ b/plugins/org.eclipse.wst.common.modulecore/modulecore-src/org/eclipse/wst/common/componentcore/internal/builder/DependencyGraphManager.java
@@ -6,6 +6,7 @@ import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.jem.util.emf.workbench.ProjectUtilities;
import org.eclipse.wst.common.componentcore.ComponentCore;
+import org.eclipse.wst.common.componentcore.internal.util.IModuleConstants;
import org.eclipse.wst.common.componentcore.resources.IVirtualComponent;
import org.eclipse.wst.common.componentcore.resources.IVirtualReference;
@@ -27,7 +28,7 @@ public class DependencyGraphManager {
}
public void construct(IProject project) {
- if (project!=null && project.isAccessible() && project.findMember(".wtpmodules") !=null) //$NON-NLS-1$
+ if (project!=null && project.isAccessible() && project.findMember(IModuleConstants.COMPONENT_FILE_PATH) !=null) //$NON-NLS-1$
constructIfNecessary();
}
@@ -54,7 +55,7 @@ public class DependencyGraphManager {
for (int i=0; i<projects.length; i++) {
if (projects[i]==null || !projects[i].isAccessible())
continue;
- IResource wtpModulesFile = projects[i].findMember(".wtpmodules"); //$NON-NLS-1$
+ IResource wtpModulesFile = projects[i].findMember(IModuleConstants.COMPONENT_FILE_PATH); //$NON-NLS-1$
if (wtpModulesFile != null) {
Long currentTimeStamp = new Long(wtpModulesFile.getLocalTimeStamp());
timeStamps.put(projects[i],currentTimeStamp);
@@ -89,8 +90,8 @@ public class DependencyGraphManager {
}
private boolean addTimeStamp(IProject project) {
- // Get the .wtpmodules file for the given project
- IResource wtpModulesFile = project.findMember(".wtpmodules"); //$NON-NLS-1$
+ // Get the .component file for the given project
+ IResource wtpModulesFile = project.findMember(IModuleConstants.COMPONENT_FILE_PATH); //$NON-NLS-1$
if (wtpModulesFile==null)
return false;
Long currentTimeStamp = new Long(wtpModulesFile.getLocalTimeStamp());
@@ -107,7 +108,7 @@ public class DependencyGraphManager {
* Lazy initialization and return of the key valued pair of projects and wtp modules file
* timestamps.
*
* @return HashMap of projects to wtpmodules file stamps
*/
private HashMap getWtpModuleTimeStamps() {
if (wtpModuleTimeStamps == null)
@@ -107,7 +108,7 @@ public class DependencyGraphManager {
* timestamps.
*
- * @return HashMap of projects to wtpmodules file stamps
+ * @return HashMap of projects to .component file stamps
*/
private HashMap getWtpModuleTimeStamps() {